module Hat.Data.Array
  (module Hat.Data.Ix,Array(),garray,aarray,harray,glistArray,alistArray
    ,hlistArray,(!!),(+!),(*!),gbounds,abounds,hbounds,gindices,gelems,aelems
    ,helems,gassocs,aassocs,hassocs,gaccumArray,aaccumArray,haccumArray,(!//)
    ,(+//),(*//),gaccum,aaccum,haccum,gixmap,aixmap,hixmap) where

import qualified Hat.PreludeBasic 
import qualified Prelude 
import Hat.Hack 
import qualified Hat.Hat as T 
import Hat.Hat  (WrapVal(wrapVal))
import Hat.Prelude 
import Hat.Data.Ix 
import Hat.Array 

tData_Array = T.mkModule "Data.Array" "Data/Array.hs" Prelude.False
